@@ -41,10 +41,12 @@ class OneMapAPI(object):
 
         url = "%s/%s/%s?%s" % (self.BASE_DOMAIN, api_route or self.API_ROUTE, endpoint, urllib.urlencode(params))
         rv = requests.get(url)
+
         data = {}
         error = None
         page_count = 0
         items = []
+
         try:
             data = rv.json()
             items = rv.json().pop(data.keys()[0])
@@ -294,20 +296,13 @@ class OneMapResult(object):
         self.params = params
         self.status_code = status_code
         self.page_count = int(page_count) if isinstance(page_count, basestring) else page_count
-        self.items = []
         self.error = error
         self.raw = raw
-        for i in items:
-            # Sanitise result field names
-            if 'XCOORD' in i:
-                i['X'] = float(i.pop('XCOORD'))
-            if 'YCOORD' in i:
-                i['Y'] = float(i.pop('YCOORD'))
-            self.items.append(OneMapResultItem(**i))
+        self.items = [OneMapResultItem(**i) for i in items]
 
     def filter(self, **filters):
         def do_filter(item):
-            return all(map(lambda (k,v): item.get(k, v) == v, filters.iteritems()))
+            return all(map(lambda (k,v): (item.get(k) or '').lower() == v.lower(), filters.iteritems()))
 
         return filter(do_filter, self.items)
 
@@ -332,6 +327,17 @@ class OneMapResultItem(object):
     def __init__(self, **kwargs):
         self.__raw = {k.lower(): v for k, v in kwargs.items()}
 
+        # Sanitise result field names
+        for f in ['xcoord', 'x', 'ycoord', 'y']:
+            if self.__raw.get(f):
+                self.__raw[f[0]] = float(self.__raw.pop(f))
+
+        if all([self.__raw.get('x'), self.__raw.get('y')]):
+            S = svy21.SVY21()
+            coordinates = S.computeLatLon(self.__raw['y'], self.__raw['x'])
+            self.__raw['lat'] = coordinates[0]
+            self.__raw['lng'] = coordinates[1]
+
     def __getattr__(self, name):
         try:
             return getattr(self.__raw, name)
